@@ -1,20 +1,18 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
-"""
-Django views for Deluge.
-"""
-
-import json
+"""Django views for Deluge."""
 
 from django.contrib import messages
 from django.utils.translation import gettext as _
 
-from plinth import actions, views
+from plinth import views
 
+from . import privileged
 from .forms import DelugeForm
 
 
 class DelugeAppView(views.AppView):
     """Serve configuration page."""
+
     diagnostics_module_name = 'deluge'
     form_class = DelugeForm
     app_id = 'deluge'
@@ -22,8 +20,7 @@ class DelugeAppView(views.AppView):
     def get_initial(self):
         """Get current Deluge server settings."""
         status = super().get_initial()
-        configuration = json.loads(
-            actions.superuser_run('deluge', ['get-configuration']))
+        configuration = privileged.get_configuration()
         status['storage_path'] = configuration['download_location']
         return status
 
@@ -33,12 +30,8 @@ class DelugeAppView(views.AppView):
         new_status = form.cleaned_data
 
         if old_status['storage_path'] != new_status['storage_path']:
-            new_configuration = [
-                'download_location', new_status['storage_path']
-            ]
-
-            actions.superuser_run('deluge',
-                                  ['set-configuration'] + new_configuration)
+            privileged.set_configuration(
+                download_location=new_status['storage_path'])
             messages.success(self.request, _('Configuration updated'))
 
         return super().form_valid(form)
