@@ -4,7 +4,7 @@ Forms for configuring unattended-upgrades.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth.modules import upgrades
 
@@ -33,9 +33,3 @@ class BackportsFirstbootForm(forms.Form):
     backports_enabled = forms.BooleanField(
         label=_('Activate frequent feature updates (recommended)'),
         required=False, initial=True)
-
-
-class UpdateFirstbootForm(forms.Form):
-    """Form to run or skip initial update during first boot wizard."""
-    update_now = forms.BooleanField(label=_('Update now (recommended)'),
-                                    required=False, initial=True)
